package
Version:
v0.0.0-...-791c77c
Opens a new window with list of versions in this module.
Published: May 11, 2025
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func MakePool[T any, TPtr interfaces.Ptr[T]](
New func() (TPtr, error),
Reset func(TPtr),
) *pool[T, TPtr]
Source Files
¶
Click to show internal directories.
Click to hide internal directories.