inventory_list_store

package
v0.0.0-...-791c77c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2025 License: MIT Imports: 30 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrEmpty = errors.New("empty")

Functions

This section is empty.

Types

type Store

type Store struct {
	// contains filtered or unexported fields
}

func (*Store) AddObjectToOpenList

func (store *Store) AddObjectToOpenList(
	openList *sku.OpenList,
	object *sku.Transacted,
) (err error)

func (*Store) Commit

func (store *Store) Commit(
	externalLike sku.ExternalLike,
	_ sku.CommitOptions,
) (err error)

func (*Store) Create

func (store *Store) Create(
	openList *sku.OpenList,
) (object *sku.Transacted, err error)

func (*Store) Flush

func (s *Store) Flush() (err error)

func (*Store) FormatForVersion

func (s *Store) FormatForVersion(sv interfaces.StoreVersion) sku.ListFormat

func (*Store) GetBlobStore

func (s *Store) GetBlobStore() interfaces.BlobStore

func (*Store) GetEnv

func (s *Store) GetEnv() env_ui.Env

func (*Store) GetEnvRepo

func (s *Store) GetEnvRepo() env_repo.Env

func (*Store) GetImmutableConfigPrivate

func (s *Store) GetImmutableConfigPrivate() config_immutable_io.ConfigLoadedPrivate

func (*Store) GetImmutableConfigPublic

func (s *Store) GetImmutableConfigPublic() config_immutable_io.ConfigLoadedPublic

func (*Store) GetInventoryListStore

func (s *Store) GetInventoryListStore() sku.InventoryListStore

func (*Store) GetObjectStore

func (s *Store) GetObjectStore() sku.ObjectStore

func (*Store) GetTai

func (s *Store) GetTai() ids.Tai

func (*Store) GetTypedInventoryListBlobStore

func (s *Store) GetTypedInventoryListBlobStore() typed_blob_store.InventoryList

func (*Store) ImportInventoryList

func (store *Store) ImportInventoryList(
	remoteBlobStore interfaces.BlobStore,
	object *sku.Transacted,
) (err error)

TODO split into public and private parts, where public includes writing the skus AND the list, while private writes just the list

func (*Store) ImportList

func (store *Store) ImportList(
	list *sku.List,
	importer sku.Importer,
) (err error)

func (*Store) Initialize

func (s *Store) Initialize(
	envRepo env_repo.Env,
	clock ids.Clock,
	typedBlobStore typed_blob_store.InventoryList,
) (err error)

func (*Store) IterAllSkus

func (store *Store) IterAllSkus() iter.Seq2[sku.ObjectWithList, error]

func (*Store) IterInventoryList

func (s *Store) IterInventoryList(
	blobSha interfaces.Sha,
) iter.Seq2[*sku.Transacted, error]

func (*Store) Lock

func (store *Store) Lock() error

func (*Store) MakeImporter

func (store *Store) MakeImporter(
	options sku.ImporterOptions,
	storeOptions sku.StoreOptions,
) sku.Importer

func (*Store) MakeOpenList

func (store *Store) MakeOpenList() (openList *sku.OpenList, err error)

func (*Store) ReadAllSkus

func (store *Store) ReadAllSkus(
	f func(listSku, sk *sku.Transacted) error,
) (err error)

func (*Store) ReadAllSorted

func (store *Store) ReadAllSorted(
	output interfaces.FuncIter[*sku.Transacted],
) (err error)

func (*Store) ReadLast

func (store *Store) ReadLast() (max *sku.Transacted, err error)

func (*Store) ReadOneInto

func (store *Store) ReadOneInto(
	oid interfaces.ObjectId,
	_ *sku.Transacted,
) (err error)

func (*Store) ReadPrimitiveQuery

func (s *Store) ReadPrimitiveQuery(
	queryGroup sku.PrimitiveQueryGroup,
	output interfaces.FuncIter[*sku.Transacted],
) (err error)

TODO

func (*Store) SetUIDelegate

func (s *Store) SetUIDelegate(ud sku.UIStorePrinters)

func (*Store) Unlock

func (store *Store) Unlock() error

func (*Store) WriteInventoryListBlob

func (store *Store) WriteInventoryListBlob(
	remoteBlobStore interfaces.BlobStore,
	object *sku.Transacted,
	list *sku.List,
) (err error)

Jump to