local_working_copy

package
v0.0.0-...-791c77c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 11, 2025 License: MIT Imports: 58 Imported by: 0

Documentation

Index

Constants

const (
	OptionsEmpty                = Options(iota)
	OptionsAllowConfigReadError = Options(1 << iota)
)

Variables

This section is empty.

Functions

func IsErrUnsupportedFormatterValue

func IsErrUnsupportedFormatterValue(err error) bool

func MakeErrUnsupportedFormatterValue

func MakeErrUnsupportedFormatterValue(
	formatValue string,
	g interfaces.Genre,
) error

Types

type ErrUnsupportedFormatterValue

type ErrUnsupportedFormatterValue interface {
	error
	GetFormatValue() string
	interfaces.GenreGetter
}

type Format

type Format struct {
	*Repo
	// contains filtered or unexported fields
}

func (*Format) Format

func (u *Format) Format(
	sk *sku.Transacted,
) (err error)

func (*Format) Set

func (f *Format) Set(v string) (err error)

func (*Format) String

func (f *Format) String() string

type Options

type Options int

func (Options) GetAllowConfigReadError

func (o Options) GetAllowConfigReadError() bool

type OptionsGetter

type OptionsGetter interface {
	GetLocalRepoOptions() Options
}

type ParentNegotiatorFirstAncestor

type ParentNegotiatorFirstAncestor struct {
	Local, Remote repo.WorkingCopy
}

func (ParentNegotiatorFirstAncestor) FindBestCommonAncestor

func (parentNegotiator ParentNegotiatorFirstAncestor) FindBestCommonAncestor(
	conflicted sku.Conflicted,
) (ancestor *sku.Transacted, err error)

func (ParentNegotiatorFirstAncestor) GetParentNegotiator

func (parentNegotiator ParentNegotiatorFirstAncestor) GetParentNegotiator() sku.ParentNegotiator

type Repo

type Repo struct {
	DormantCounter query.DormantCounter
	// contains filtered or unexported fields
}

func Genesis

func Genesis(
	bb env_repo.BigBang,
	repoLayout env_repo.Env,
) (repo *Repo)

func Make

func Make(
	env env_local.Env,
	options Options,
) *Repo

func MakeWithLayout

func MakeWithLayout(
	options Options,
	envRepo env_repo.Env,
) (repo *Repo)

func (*Repo) ApplyToOrganizeOptions

func (e *Repo) ApplyToOrganizeOptions(oo *organize_text.Options)

func (*Repo) Checkin

func (repo *Repo) Checkin(
	skus sku.SkuTypeSetMutable,
	proto sku.Proto,
	delete bool,
	refreshCheckout bool,
) (processed sku.TransactedMutableSet, err error)

func (*Repo) DeleteFiles

func (u *Repo) DeleteFiles(fs interfaces.Collection[*fd.FD]) (err error)

func (*Repo) Flush

func (repo *Repo) Flush() (err error)

func (*Repo) GetAbbr

func (repo *Repo) GetAbbr() sku.AbbrStore

func (*Repo) GetBlobFormatter

func (repo *Repo) GetBlobFormatter(
	tipe ids.Type,
	formatId string,
	utiGroup string,
) (blobFormatter script_config.RemoteScript, err error)

TODO add support for checked out types

func (*Repo) GetBlobStore

func (u *Repo) GetBlobStore() interfaces.BlobStore

func (*Repo) GetConfig

func (u *Repo) GetConfig() store_config.Store

func (*Repo) GetDormantIndex

func (u *Repo) GetDormantIndex() *dormant_index.Index

func (*Repo) GetEnv

func (u *Repo) GetEnv() env_ui.Env

func (*Repo) GetEnvLocal

func (repo *Repo) GetEnvLocal() env_local.Env

func (*Repo) GetEnvLua

func (u *Repo) GetEnvLua() env_lua.Env

func (*Repo) GetEnvRepo

func (u *Repo) GetEnvRepo() env_repo.Env

func (*Repo) GetEnvWorkspace

func (repo *Repo) GetEnvWorkspace() env_workspace.Env

func (*Repo) GetImmutableConfigPrivate

func (u *Repo) GetImmutableConfigPrivate() config_immutable_io.ConfigLoadedPrivate

func (*Repo) GetImmutableConfigPublic

func (u *Repo) GetImmutableConfigPublic() config_immutable_io.ConfigLoadedPublic

func (*Repo) GetInventoryListStore

func (u *Repo) GetInventoryListStore() sku.InventoryListStore

func (*Repo) GetMatcherDormant

func (u *Repo) GetMatcherDormant() query.DormantCounter

func (*Repo) GetObjectFromObjectId

func (repo *Repo) GetObjectFromObjectId(
	objectIdString string,
) (sk *sku.Transacted, err error)

func (*Repo) GetObjectStore

func (repo *Repo) GetObjectStore() sku.ObjectStore

func (*Repo) GetStore

func (u *Repo) GetStore() *store.Store

func (*Repo) GetTime

func (u *Repo) GetTime() time.Time

func (*Repo) GetTypedInventoryListBlobStore

func (u *Repo) GetTypedInventoryListBlobStore() typed_blob_store.InventoryList

func (*Repo) GetWorkspaceStoreForQuery

func (repo *Repo) GetWorkspaceStoreForQuery(
	repoId ids.RepoId,
) (store_workspace.Store, bool)

func (*Repo) GetZettelFromObjectId

func (repo *Repo) GetZettelFromObjectId(
	objectIdString string,
) (sk *sku.Transacted, err error)

TODO rename

func (*Repo) ImportList

func (repo *Repo) ImportList(
	list *sku.List,
	i sku.Importer,
) (err error)

func (*Repo) Lock

func (u *Repo) Lock() (err error)

func (*Repo) LockAndCommitOrganizeResults

func (repo *Repo) LockAndCommitOrganizeResults(
	results organize_text.OrganizeResults,
) (changeResults organize_text.Changes, err error)

func (*Repo) MakeExternalQueryGroup

func (repo *Repo) MakeExternalQueryGroup(
	metaBuilder query.BuilderOption,
	externalQueryOptions sku.ExternalQueryOptions,
	args ...string,
) (queryGroup *query.Query, err error)

func (*Repo) MakeFormatFunc

func (repo *Repo) MakeFormatFunc(
	format string,
	writer interfaces.WriterAndStringWriter,
) (output interfaces.FuncIter[*sku.Transacted], err error)

TODO switch to using fd.Std

func (*Repo) MakeImporter

func (repo *Repo) MakeImporter(
	options sku.ImporterOptions,
	storeOptions sku.StoreOptions,
) (importer sku.Importer)

func (*Repo) MakeInventoryList

func (u *Repo) MakeInventoryList(
	queryGroup *query.Query,
) (list *sku.List, err error)

func (*Repo) MakeObjectIdIndex

func (u *Repo) MakeObjectIdIndex() ids.Index

func (*Repo) MakeOrganizeOptionsWithOrganizeMetadata

func (e *Repo) MakeOrganizeOptionsWithOrganizeMetadata(
	organizeFlags organize_text.Flags,
	metadata organize_text.Metadata,
) organize_text.Options

func (*Repo) MakeOrganizeOptionsWithQueryGroup

func (e *Repo) MakeOrganizeOptionsWithQueryGroup(
	organizeFlags organize_text.Flags,
	qg *query.Query,
) organize_text.Options

func (*Repo) MakePrinterBoxArchive

func (u *Repo) MakePrinterBoxArchive(
	out interfaces.WriterAndStringWriter,
	includeTai bool,
) interfaces.FuncIter[*sku.Transacted]

func (*Repo) MakeQueryBuilder

func (repo *Repo) MakeQueryBuilder(
	dg ids.Genre,
	options query.BuilderOption,
) *query.Builder

func (*Repo) MakeQueryBuilderExcludingHidden

func (repo *Repo) MakeQueryBuilderExcludingHidden(
	genre ids.Genre,
	options query.BuilderOption,
) *query.Builder

func (*Repo) PrintMatchedDormantIfNecessary

func (u *Repo) PrintMatchedDormantIfNecessary()

func (*Repo) PrinterCheckedOutConflictsForRemoteTransfers

func (u *Repo) PrinterCheckedOutConflictsForRemoteTransfers() interfaces.FuncIter[*sku.CheckedOut]

func (*Repo) PrinterFDDeleted

func (repo *Repo) PrinterFDDeleted() interfaces.FuncIter[*fd.FD]

TODO make generic external version

func (*Repo) PrinterHeader

func (u *Repo) PrinterHeader() interfaces.FuncIter[string]

func (*Repo) PrinterTransactedDeleted

func (repo *Repo) PrinterTransactedDeleted() interfaces.FuncIter[*sku.CheckedOut]

TODO migrate to StringFormatWriterSkuBoxCheckedOut

func (*Repo) PullQueryGroupFromRemote

func (local *Repo) PullQueryGroupFromRemote(
	remote repo.Repo,
	qg *query.Query,
	options repo.RemoteTransferOptions,
) (err error)

func (*Repo) ReadObjectHistory

func (env *Repo) ReadObjectHistory(
	oid *ids.ObjectId,
) (skus []*sku.Transacted, err error)

func (*Repo) Reindex

func (localWorkingCopy *Repo) Reindex()

func (*Repo) Reset

func (u *Repo) Reset() (err error)

TODO investigate removing unnecessary resets like from organize

func (*Repo) Unlock

func (u *Repo) Unlock() (err error)

TODO print organize files that were created if dry run or make it possible to commit dry-run transactions

Jump to