Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CopyWithPrefixOnDelim ¶
func CopyWithPrefixOnDelim( delim byte, prefix string, dst ui.Printer, src io.Reader, includeLineNo bool, ) (n int64, err error)
Copies each `delim` suffixed segment from src to dst, and for each segment, adds the passed in prefix string.
Useful for taking a Reader and adding a prefix for every line, like how `git` shows `remote: <line>` for all remote stderr output. TODO extract into an io.Writer-like object
Types ¶
Click to show internal directories.
Click to hide internal directories.