Documentation
¶
Index ¶
- func BuilderOptionDefaultGenres(genres ...genres.Genre) builderOptionDefaultGenre
- func BuilderOptionDefaultSigil(sigils ...ids.Sigil) builderOptionDefaultSigil
- func BuilderOptions(options ...BuilderOption) builderOptions
- func BuilderOptionsOld(o any, remainder ...BuilderOption) builderOptions
- func ContainsExternalSku(qg *Query, el sku.ExternalLike, state checked_out_state.State) (ok bool)
- func ContainsSkuCheckedOutState(qg *Query, state checked_out_state.State) (ok bool)
- func GetTags(query *Query) ids.TagMutableSet
- func GetTypes(qg *Query) ids.TypeSet
- func IsErrBlobMissing(err error) bool
- func IsExactlyOneObjectId(qg *Query) bool
- type Builder
- func (b *Builder) BuildQueryGroup(vs ...string) (group *Query, err error)
- func (b *Builder) BuildQueryGroupWithRepoId(externalQueryOptions sku.ExternalQueryOptions, values ...string) (query *Query, err error)
- func (mb *Builder) WithDebug() *Builder
- func (mb *Builder) WithDefaultGenres(defaultGenres ids.Genre) *Builder
- func (mb *Builder) WithDefaultSigil(defaultSigil ids.Sigil) *Builder
- func (b *Builder) WithDoNotMatchEmpty() *Builder
- func (mb *Builder) WithExpanders(expanders ids.Abbr) *Builder
- func (b *Builder) WithExternalLike(zts sku.SkuTypeSet) *Builder
- func (mb *Builder) WithFileExtensions(feg interfaces.FileExtensions) *Builder
- func (mb *Builder) WithHidden(hidden sku.Query) *Builder
- func (b *Builder) WithOptions(options BuilderOption) *Builder
- func (b *Builder) WithPermittedSigil(s ids.Sigil) *Builder
- func (mb *Builder) WithRepoId(repoId ids.RepoId) *Builder
- func (b *Builder) WithRequireNonEmptyQuery() *Builder
- func (b *Builder) WithTransacted(zts sku.TransactedSet, sigil ids.Sigil) *Builder
- type BuilderOption
- type BuilderOptionGetter
- type BuilderOptionWorkspace
- type BuilderOptionWorkspaceConfigGetter
- type BuilderOptionsMulti
- type CompoundMatch
- type DormantCounter
- type ErrBlobMissing
- type ExecutionInfo
- type Executor
- func (executor *Executor) ExecuteExactlyOne() (sk *sku.Transacted, err error)
- func (executor *Executor) ExecuteExactlyOneExternalObject(permitInternal bool) (object *sku.Transacted, err error)
- func (executor *Executor) ExecuteSkuType(out interfaces.FuncIter[sku.SkuType]) (err error)
- func (e *Executor) ExecuteTransacted(out interfaces.FuncIter[*sku.Transacted]) (err error)
- func (e *Executor) ExecuteTransactedAsSkuType(out interfaces.FuncIter[sku.SkuType]) (err error)
- func (qg Executor) Get(g genres.Genre) (sku.QueryWithSigilAndObjectId, bool)
- func (qg Executor) GetSigil() (s ids.Sigil)
- func (qg Executor) HasHidden() bool
- type ExecutorPrimitive
- type ObjectId
- type Query
- type QueryBuilderModifier
- type QueryCheckedOut
- type Tags
- func (sch *Tags) AddTag(e *tag_paths.Tag) (err error)
- func (sch *Tags) ContainsSku(sk *sku.Transacted) bool
- func (sch *Tags) Flush(s env_repo.Env, printerHeader interfaces.FuncIter[string], dryRun bool) (err error)
- func (sch *Tags) GetChanges() (out []string)
- func (sch *Tags) HasChanges() bool
- func (sch *Tags) Load(s env_repo.Env) (err error)
- func (s *Tags) ReadFrom(r *bufio.Reader) (n int64, err error)
- func (sch *Tags) RemoveDormantTag(e *tag_paths.Tag) (err error)
- func (s Tags) WriteTo(w io.Writer) (n int64, err error)
- type WorkspaceStore
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuilderOptions ¶
func BuilderOptions(options ...BuilderOption) builderOptions
nil options are permitted, they are just skipped during application
func BuilderOptionsOld ¶
func BuilderOptionsOld(o any, remainder ...BuilderOption) builderOptions
func ContainsExternalSku ¶
func ContainsExternalSku( qg *Query, el sku.ExternalLike, state checked_out_state.State, ) (ok bool)
func ContainsSkuCheckedOutState ¶
func ContainsSkuCheckedOutState( qg *Query, state checked_out_state.State, ) (ok bool)
func GetTags ¶
func GetTags(query *Query) ids.TagMutableSet
func IsErrBlobMissing ¶
func IsExactlyOneObjectId ¶
Types ¶
type Builder ¶
type Builder struct {
// contains filtered or unexported fields
}
func MakeBuilder ¶
func MakeBuilder( envRepo env_repo.Env, typedBlobStore typed_blob_store.Stores, objectProbeIndex sku.ObjectProbeIndex, luaVMPoolBuilder *lua.VMPoolBuilder, workspaceStoreGetter store_workspace.StoreGetter, ) (b *Builder)
func (*Builder) BuildQueryGroup ¶
func (*Builder) BuildQueryGroupWithRepoId ¶
func (*Builder) WithDefaultGenres ¶
TODO refactor into BuilderOption
func (*Builder) WithDefaultSigil ¶
TODO refactor into BuilderOption
func (*Builder) WithDoNotMatchEmpty ¶
TODO refactor into BuilderOption
func (*Builder) WithExpanders ¶
TODO refactor into BuilderOption
func (*Builder) WithExternalLike ¶
func (b *Builder) WithExternalLike( zts sku.SkuTypeSet, ) *Builder
TODO
func (*Builder) WithFileExtensions ¶
func (mb *Builder) WithFileExtensions( feg interfaces.FileExtensions, ) *Builder
TODO refactor into BuilderOption
func (*Builder) WithOptions ¶
func (b *Builder) WithOptions(options BuilderOption) *Builder
func (*Builder) WithPermittedSigil ¶
TODO refactor into BuilderOption
func (*Builder) WithRepoId ¶
TODO refactor into BuilderOption
func (*Builder) WithRequireNonEmptyQuery ¶
TODO refactor into BuilderOption
func (*Builder) WithTransacted ¶
type BuilderOption ¶
type BuilderOptionGetter ¶
type BuilderOptionGetter interface {
GetQueryBuilderOptions() builderOptionsOld
}
type BuilderOptionWorkspace ¶
type BuilderOptionWorkspace struct {
Env BuilderOptionWorkspaceConfigGetter
}
func (BuilderOptionWorkspace) Apply ¶
func (options BuilderOptionWorkspace) Apply(builder *Builder) *Builder
type BuilderOptionWorkspaceConfigGetter ¶
type BuilderOptionWorkspaceConfigGetter interface {
GetWorkspaceConfig() workspace_config_blobs.Blob
}
type BuilderOptionsMulti ¶
type BuilderOptionsMulti []BuilderOption
type CompoundMatch ¶
func (*CompoundMatch) ContainsSku ¶
func (k *CompoundMatch) ContainsSku(tg sku.TransactedGetter) bool
func (*CompoundMatch) String ¶
func (k *CompoundMatch) String() string
type DormantCounter ¶
func MakeDormantCounter ¶
func MakeDormantCounter() DormantCounter
type ErrBlobMissing ¶
type ErrBlobMissing struct {
ObjectId
env_dir.ErrBlobMissing
}
func (ErrBlobMissing) Is ¶
func (e ErrBlobMissing) Is(target error) bool
type ExecutionInfo ¶
type ExecutionInfo struct {
WorkspaceStore
sku.FuncPrimitiveQuery
sku.FuncReadOneInto
}
type Executor ¶
type Executor struct {
ExecutionInfo
Out interfaces.FuncIter[sku.ExternalLike]
// contains filtered or unexported fields
}
TODO use ExecutorPrimitive
func MakeExecutorWithExternalStore ¶
func MakeExecutorWithExternalStore( query *Query, fpq sku.FuncPrimitiveQuery, froi sku.FuncReadOneInto, workspaceStore WorkspaceStore, ) Executor
func (*Executor) ExecuteExactlyOne ¶
func (executor *Executor) ExecuteExactlyOne() (sk *sku.Transacted, err error)
func (*Executor) ExecuteExactlyOneExternalObject ¶
func (executor *Executor) ExecuteExactlyOneExternalObject( permitInternal bool, ) (object *sku.Transacted, err error)
TODO refactor into methods that have internal in the name
func (*Executor) ExecuteSkuType ¶
func (*Executor) ExecuteTransacted ¶
func (e *Executor) ExecuteTransacted( out interfaces.FuncIter[*sku.Transacted], ) (err error)
func (*Executor) ExecuteTransactedAsSkuType ¶
type ExecutorPrimitive ¶
type ExecutorPrimitive struct {
// contains filtered or unexported fields
}
func MakeExecutorPrimitive ¶
func MakeExecutorPrimitive( qg sku.PrimitiveQueryGroup, fpq sku.FuncPrimitiveQuery, froi sku.FuncReadOneInto, ) ExecutorPrimitive
func (*ExecutorPrimitive) ExecuteExternalLike ¶
func (e *ExecutorPrimitive) ExecuteExternalLike( out interfaces.FuncIter[sku.ExternalLike], ) (err error)
func (*ExecutorPrimitive) ExecuteTransacted ¶
func (e *ExecutorPrimitive) ExecuteTransacted( out interfaces.FuncIter[*sku.Transacted], ) (err error)
type ObjectId ¶
func (ObjectId) ContainsSku ¶
func (exp ObjectId) ContainsSku(tg sku.TransactedGetter) (ok bool)
TODO support exact
type Query ¶
type Query struct {
sku.ExternalQueryOptions
// contains filtered or unexported fields
}
func (*Query) GetDefaultQuery ¶
func (*Query) StringDebug ¶
func (*Query) StringOptimized ¶
type QueryBuilderModifier ¶
type QueryBuilderModifier interface {
ModifyBuilder(*Builder)
}
type QueryCheckedOut ¶
type Tags ¶
type Tags struct {
// contains filtered or unexported fields
}
TODO move implicit tags here
func (*Tags) ContainsSku ¶
func (sch *Tags) ContainsSku(sk *sku.Transacted) bool
func (*Tags) GetChanges ¶
func (*Tags) HasChanges ¶
type WorkspaceStore ¶
type WorkspaceStore interface {
interfaces.WorkspaceStoreReadAllExternalItems
sku.ExternalStoreUpdateTransacted
sku.ExternalStoreReadExternalLikeFromObjectIdLike
QueryCheckedOut
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.