Documentation
¶
Index ¶
- Variables
- type Store
- func (store *Store) AddObjectToOpenList(openList *sku.OpenList, object *sku.Transacted) (err error)
- func (store *Store) Commit(externalLike sku.ExternalLike, _ sku.CommitOptions) (err error)
- func (store *Store) Create(openList *sku.OpenList) (object *sku.Transacted, err error)
- func (s *Store) Flush() (err error)
- func (s *Store) FormatForVersion(sv interfaces.StoreVersion) sku.ListFormat
- func (s *Store) GetBlobStore() interfaces.BlobStore
- func (s *Store) GetEnv() env_ui.Env
- func (s *Store) GetEnvRepo() env_repo.Env
- func (s *Store) GetImmutableConfigPrivate() config_immutable_io.ConfigLoadedPrivate
- func (s *Store) GetImmutableConfigPublic() config_immutable_io.ConfigLoadedPublic
- func (s *Store) GetInventoryListStore() sku.InventoryListStore
- func (s *Store) GetObjectStore() sku.ObjectStore
- func (s *Store) GetTai() ids.Tai
- func (s *Store) GetTypedInventoryListBlobStore() typed_blob_store.InventoryList
- func (store *Store) ImportInventoryList(remoteBlobStore interfaces.BlobStore, object *sku.Transacted) (err error)
- func (store *Store) ImportList(list *sku.List, importer sku.Importer) (err error)
- func (s *Store) Initialize(envRepo env_repo.Env, clock ids.Clock, ...) (err error)
- func (store *Store) IterAllSkus() iter.Seq2[sku.ObjectWithList, error]
- func (s *Store) IterInventoryList(blobSha interfaces.Sha) iter.Seq2[*sku.Transacted, error]
- func (store *Store) Lock() error
- func (store *Store) MakeImporter(options sku.ImporterOptions, storeOptions sku.StoreOptions) sku.Importer
- func (store *Store) MakeOpenList() (openList *sku.OpenList, err error)
- func (store *Store) ReadAllSkus(f func(listSku, sk *sku.Transacted) error) (err error)
- func (store *Store) ReadAllSorted(output interfaces.FuncIter[*sku.Transacted]) (err error)
- func (store *Store) ReadLast() (max *sku.Transacted, err error)
- func (store *Store) ReadOneInto(oid interfaces.ObjectId, _ *sku.Transacted) (err error)
- func (s *Store) ReadPrimitiveQuery(queryGroup sku.PrimitiveQueryGroup, ...) (err error)
- func (s *Store) SetUIDelegate(ud sku.UIStorePrinters)
- func (store *Store) Unlock() error
- func (store *Store) WriteInventoryListBlob(remoteBlobStore interfaces.BlobStore, object *sku.Transacted, list *sku.List) (err error)
Constants ¶
This section is empty.
Variables ¶
var ErrEmpty = errors.New("empty")
Functions ¶
This section is empty.
Types ¶
type Store ¶
type Store struct {
// contains filtered or unexported fields
}
func (*Store) AddObjectToOpenList ¶
func (*Store) Commit ¶
func (store *Store) Commit( externalLike sku.ExternalLike, _ sku.CommitOptions, ) (err error)
func (*Store) FormatForVersion ¶
func (s *Store) FormatForVersion(sv interfaces.StoreVersion) sku.ListFormat
func (*Store) GetBlobStore ¶
func (s *Store) GetBlobStore() interfaces.BlobStore
func (*Store) GetEnvRepo ¶
func (*Store) GetImmutableConfigPrivate ¶
func (s *Store) GetImmutableConfigPrivate() config_immutable_io.ConfigLoadedPrivate
func (*Store) GetImmutableConfigPublic ¶
func (s *Store) GetImmutableConfigPublic() config_immutable_io.ConfigLoadedPublic
func (*Store) GetInventoryListStore ¶
func (s *Store) GetInventoryListStore() sku.InventoryListStore
func (*Store) GetObjectStore ¶
func (s *Store) GetObjectStore() sku.ObjectStore
func (*Store) GetTypedInventoryListBlobStore ¶
func (s *Store) GetTypedInventoryListBlobStore() typed_blob_store.InventoryList
func (*Store) ImportInventoryList ¶
func (store *Store) ImportInventoryList( remoteBlobStore interfaces.BlobStore, object *sku.Transacted, ) (err error)
TODO split into public and private parts, where public includes writing the skus AND the list, while private writes just the list
func (*Store) ImportList ¶
func (*Store) Initialize ¶
func (s *Store) Initialize( envRepo env_repo.Env, clock ids.Clock, typedBlobStore typed_blob_store.InventoryList, ) (err error)
func (*Store) IterAllSkus ¶
func (*Store) IterInventoryList ¶
func (s *Store) IterInventoryList( blobSha interfaces.Sha, ) iter.Seq2[*sku.Transacted, error]
func (*Store) MakeImporter ¶
func (store *Store) MakeImporter( options sku.ImporterOptions, storeOptions sku.StoreOptions, ) sku.Importer
func (*Store) ReadAllSkus ¶
func (store *Store) ReadAllSkus( f func(listSku, sk *sku.Transacted) error, ) (err error)
func (*Store) ReadAllSorted ¶
func (store *Store) ReadAllSorted( output interfaces.FuncIter[*sku.Transacted], ) (err error)
func (*Store) ReadOneInto ¶
func (store *Store) ReadOneInto( oid interfaces.ObjectId, _ *sku.Transacted, ) (err error)
func (*Store) ReadPrimitiveQuery ¶
func (s *Store) ReadPrimitiveQuery( queryGroup sku.PrimitiveQueryGroup, output interfaces.FuncIter[*sku.Transacted], ) (err error)
TODO
func (*Store) SetUIDelegate ¶
func (s *Store) SetUIDelegate(ud sku.UIStorePrinters)
func (*Store) WriteInventoryListBlob ¶
func (store *Store) WriteInventoryListBlob( remoteBlobStore interfaces.BlobStore, object *sku.Transacted, list *sku.List, ) (err error)
Click to show internal directories.
Click to hide internal directories.